==> nextcloud-13.0.4-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/lv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with you" : "Koplietots ar tevi",
    "Shared with others" : "Koplietots ar citiem",
    "Shared by link" : "Koplietots ar saiti",
    "Nothing shared with you yet" : "Nekas vēl nav koplietots",
    "Files and folders others share with you will show up here" : "Datnes un mapes, ko citi koplietos ar tevi, tiks rādīti šeit",
    "Nothing shared yet" : "Nekas vēl nav koplietots",
    "Files and folders you share will show up here" : "Datnes un mapes, ko koplietosi ar citiem, tiks rādīti šeit",
    "No shared links" : "Nav koplietotu saišu",
    "Files and folders you share by link will show up here" : "Datnes un mapes, ko koplietosi ar saitēm, tiks rādīti šeit",
    "You can upload into this folder" : "Jūs variet augšuplādēt šajā mapē",
    "No compatible server found at {remote}" : "Nav atrasts neviens saderīgs serveris {remote}",
    "Invalid server URL" : "Nederīgs servera url",
    "Failed to add the public link to your Nextcloud" : "Neizdevās pievienot publisku saiti jūsu Nextcloud",
    "Share" : "Koplietot",
    "No expiration date set" : "Nav noteikts derīguma termiņa beigu datums",
    "Shared by" : "Koplietoja",
    "Sharing" : "Koplietošana",
    "File shares" : "Datņu koplietojumi",
    "Downloaded via public link" : "Lejupielādēt izmantojot publisku saiti",
    "Downloaded by {email}" : "Lejupielādēts {email}",
    "{file} downloaded via public link" : "{file} lejupielādēts izmantojot publisku saiti",
    "{email} downloaded {file}" : "{email} lejupielādēts {file}",
    "Shared with group {group}" : "Koplietots ar grupu {group}",
    "{actor} removed group {group} from {file}" : "{actor} noņēma grupu {group} no {file}",
    "Shared as public link" : "Koplietots kā publiska saite",
    "Removed public link" : "Noņemta publiska saite",
    "Shared with {user}" : "Koplietots ar {user}",
    "{actor} shared with {user}" : "{actor} koplieto ar {user}",
    "Shared by {actor}" : "Koplietoja {actor}",
    "{actor} removed {user} from {file}" : "{actor} noņemts {user} no {file}",
    "{actor} shared {file} with you" : "{actor} koplietots {file} ar jums",
    "{actor} removed you from {file}" : "{actor} noņēma jūs no {file}",
    "A file or folder was shared from <strong>another server</strong>" : "Datne vai mape tika koplietota no <strong>cita servera</strong>",
    "A file or folder has been <strong>shared</strong>" : "<strong>Koplietota</strong> datne vai mape",
    "Wrong share ID, share doesn't exist" : "Nepareizs koplietošanas ID, koplietotne neeksistē",
    "could not delete share" : "neizdevās dzēst koplietotni",
    "Could not delete share" : "Neizdevās dzēst koplietotni",
    "Please specify a file or folder path" : "Lūdzu norādiet datnes vai mapes ceļu",
    "Wrong path, file/folder doesn't exist" : "Nepareizs ceļš, datne/mape neeksistē",
    "Could not create share" : "Nevar izveidot koplietošanu",
    "invalid permissions" : "Nederīgas atļaujas",
    "Please specify a valid user" : "Lūdzu norādiet derīgu lietotāju",
    "Group sharing is disabled by the administrator" : "Administrators grupas koplietošanu ir atslēdzis",
    "Please specify a valid group" : "Lūdzu norādiet derīgu grupu",
    "Public link sharing is disabled by the administrator" : "Administrators publisku saites koplietošanu ir atslēdzis",
    "Public upload disabled by the administrator" : "Administrators publisku augšupielādi ir atslēdzis",
    "Public upload is only possible for publicly shared folders" : "Publiska augšupielāde iespējama tikai publiski koplietotām mapēm",
    "Invalid date, date format must be YYYY-MM-DD" : "Nepareizs datums, datumam jābūt YYYY-MM-DD formātā",
    "Unknown share type" : "Nezināms koplietošanas tips",
    "Not a directory" : "Nav direktorijs",
    "Could not lock path" : "Nevarēja bloķēt ceļu",
    "Can't change permissions for public share links" : "Publiskai koplietošanas saitei nevar mainīt tiesības",
    "Cannot increase permissions" : "Nevar palielināt tiesības",
    "Download" : "Lejupielādēt",
    "Direct link" : "Tiešā saite",
    "Add to your Nextcloud" : "Pievienot savam Nextcloud",
    "Share API is disabled" : "Koplietošanas API ir atslēgta",
    "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
    "Password" : "Parole",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Name" : "Nosaukums",
    "Share time" : "Koplietošanas laiks",
    "Expiration date" : "Termiņa datums",
    "Sorry, this link doesn’t seem to work anymore." : "Izskatās, ka šī saite vairs nedarbojas",
    "Reasons might be:" : "Iespējamie iemesli:",
    "the item was removed" : "vienums tika dzēsts",
    "the link expired" : "saitei beidzies termiņš",
    "sharing is disabled" : "koplietošana nav ieslēgta",
    "For more info, please ask the person who sent this link." : "Vairāk informācijas vaicā personai, kas nosūtīja šo saiti.",
    "Download %s" : "Lejupielādēt %s",
    "Uploading files…" : "Augšupielādē datnes",
    "Uploaded files:" : "Augšupielādēti faili:"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");

==> nextcloud-13.0.5-1-any.pkg.tar.xz: usr/share/webapps/nextcloud/apps/files_sharing/l10n/lv.js <==
OC.L10N.register(
    "files_sharing",
    {
    "Shared with others" : "Koplietots ar citiem",
    "Shared with you" : "Koplietots ar tevi",
    "Shared by link" : "Koplietots ar saiti",
    "Nothing shared with you yet" : "Nekas vēl nav koplietots",
    "Files and folders others share with you will show up here" : "Datnes un mapes, ko citi koplietos ar tevi, tiks rādīti šeit",
    "Nothing shared yet" : "Nekas vēl nav koplietots",
    "Files and folders you share will show up here" : "Datnes un mapes, ko koplietosi ar citiem, tiks rādīti šeit",
    "No shared links" : "Nav koplietotu saišu",
    "Files and folders you share by link will show up here" : "Datnes un mapes, ko koplietosi ar saitēm, tiks rādīti šeit",
    "You can upload into this folder" : "Jūs variet augšuplādēt šajā mapē",
    "No compatible server found at {remote}" : "Nav atrasts neviens saderīgs serveris {remote}",
    "Invalid server URL" : "Nederīgs servera url",
    "Failed to add the public link to your Nextcloud" : "Neizdevās pievienot publisku saiti jūsu Nextcloud",
    "Share" : "Koplietot",
    "No expiration date set" : "Nav noteikts derīguma termiņa beigu datums",
    "Shared by" : "Koplietoja",
    "Sharing" : "Koplietošana",
    "File shares" : "Datņu koplietojumi",
    "Downloaded via public link" : "Lejupielādēt izmantojot publisku saiti",
    "Downloaded by {email}" : "Lejupielādēts {email}",
    "{file} downloaded via public link" : "{file} lejupielādēts izmantojot publisku saiti",
    "{email} downloaded {file}" : "{email} lejupielādēts {file}",
    "Shared with group {group}" : "Koplietots ar grupu {group}",
    "{actor} removed group {group} from {file}" : "{actor} noņēma grupu {group} no {file}",
    "Shared as public link" : "Koplietots kā publiska saite",
    "Removed public link" : "Noņemta publiska saite",
    "Shared with {user}" : "Koplietots ar {user}",
    "{actor} shared with {user}" : "{actor} koplieto ar {user}",
    "Shared by {actor}" : "Koplietoja {actor}",
    "{actor} removed {user} from {file}" : "{actor} noņemts {user} no {file}",
    "{actor} shared {file} with you" : "{actor} koplietots {file} ar jums",
    "A file or folder was shared from <strong>another server</strong>" : "Datne vai mape tika koplietota no <strong>cita servera</strong>",
    "A file or folder has been <strong>shared</strong>" : "<strong>Koplietota</strong> datne vai mape",
    "Wrong share ID, share doesn't exist" : "Nepareizs koplietošanas ID, koplietotne neeksistē",
    "could not delete share" : "neizdevās dzēst koplietotni",
    "Could not delete share" : "Neizdevās dzēst koplietotni",
    "Please specify a file or folder path" : "Lūdzu norādiet datnes vai mapes ceļu",
    "Wrong path, file/folder doesn't exist" : "Nepareizs ceļš, datne/mape neeksistē",
    "Could not create share" : "Nevar izveidot koplietošanu",
    "invalid permissions" : "Nederīgas atļaujas",
    "Please specify a valid user" : "Lūdzu norādiet derīgu lietotāju",
    "Group sharing is disabled by the administrator" : "Administrators grupas koplietošanu ir atslēdzis",
    "Please specify a valid group" : "Lūdzu norādiet derīgu grupu",
    "Public link sharing is disabled by the administrator" : "Administrators publisku saites koplietošanu ir atslēdzis",
    "Public upload disabled by the administrator" : "Administrators publisku augšupielādi ir atslēdzis",
    "Public upload is only possible for publicly shared folders" : "Publiska augšupielāde iespējama tikai publiski koplietotām mapēm",
    "Invalid date, date format must be YYYY-MM-DD" : "Nepareizs datums, datumam jābūt YYYY-MM-DD formātā",
    "Unknown share type" : "Nezināms koplietošanas tips",
    "Not a directory" : "Nav direktorijs",
    "Could not lock path" : "Nevarēja bloķēt ceļu",
    "Can't change permissions for public share links" : "Publiskai koplietošanas saitei nevar mainīt tiesības",
    "Cannot increase permissions" : "Nevar palielināt tiesības",
    "Download" : "Lejupielādēt",
    "Direct link" : "Tiešā saite",
    "Add to your Nextcloud" : "Pievienot savam Nextcloud",
    "Share API is disabled" : "Koplietošanas API ir atslēgta",
    "No entries found in this folder" : "Šajā mapē nekas nav atrasts",
    "Name" : "Nosaukums",
    "Share time" : "Koplietošanas laiks",
    "Expiration date" : "Termiņa datums",
    "Sorry, this link doesn’t seem to work anymore." : "Izskatās, ka šī saite vairs nedarbojas",
    "Reasons might be:" : "Iespējamie iemesli:",
    "the item was removed" : "vienums tika dzēsts",
    "the link expired" : "saitei beidzies termiņš",
    "sharing is disabled" : "koplietošana nav ieslēgta",
    "For more info, please ask the person who sent this link." : "Vairāk informācijas vaicā personai, kas nosūtīja šo saiti.",
    "Download %s" : "Lejupielādēt %s",
    "Uploading files…" : "Augšupielādē datnes",
    "Uploaded files:" : "Augšupielādēti faili:",
    "{actor} removed you from {file}" : "{actor} noņēma jūs no {file}",
    "This share is password-protected" : "Šī koplietotne ir aizsargāta ar paroli",
    "The password is wrong. Try again." : "Nepareiza parole. Mēģiniet vēlreiz.",
    "Password" : "Parole"
},
"nplurals=3; plural=(n%10==1 && n%100!=11 ? 0 : n != 0 ? 1 : 2);");
